.. SQUAD documentation master file, created by
   sphinx-quickstart on Wed Oct 11 17:16:09 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

SQUAD — Software Quality Dashboard
==================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   intro
   quickstart
   hacking
   plugins
   install
   ci
   api
   lava_usecase

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
